django-geopostcodes — django-geopostcodes 0.1.0 documentation

# django-geopostcodes

Django modelling for geopostcodes.com

NOTE: This repository does not include the actual data, you must purchase this from geopostcodes.com and then import it as per the following documentation.

`django-geopostcodes` supports Python 2.7, 3.3, 3.4 and pypy for Django 1.7 and 1.8.

## Contents

- Installation
- Usage
- Developer Documentation
- Internal Module Reference

## License

This software is licensed under the MIT License. See the LICENSE file in the top distribution directory for the full license text.

## Author

Alex Hayes <alex@alution.com>